## `pyABCI` ABCI 2.0 protocol implementation

This implementation is asynchronous with minimal dependencies and as simple 
as possible. The repository contains a working example of KVStore, which 
corresponds in functionality to what is included in the CometBFT repository.

